<h1 align="center"><a href="https://youtube.com/@rajdeepchatterjee-pb5jw?si=LAEg_mWzrHpJcrp6">pythOyO</a></h1>


[![](https://github.com/RajChat-hub/pythOyO/blob/main/asyets/imyages/pythOyO_500px_Logo3.png)](https://youtube.com/@rajdeepchatterjee-pb5jw?si=LAEg_mWzrHpJcrp6)

<p align="center">
  <b>pythOyO is an uyu programming language written in Python. UyU.</b>
</p>

<p align="center">
  <a href="https://marketplace.visualstudio.com/items?itemName=Haddle.pyoyo">Get PythOyO LangUyUage support for VSCode</a>
</p>
<p align="center">
  <a href="https://pypi.org/project/PythOyO/">PythOyO on PyPi</a><br>
</p>

```bash
pip install PythOyO
```

<h2 align="center">Uyusage</h2>

<h4 align="left">Cruyueate a nuyu file - <code>test.pyoyo</code></h4>

```py
pyint("Heyyo Woyrld")
```

<h4 align="left">Ruyun</h4>

Either run from the interpreter directly:
```sh
python/python3 pythoyo.py test.pyoyo
```

Or run in an interactive shell:
```sh
python shÿell.py
(｡･ÿ･｡)ﾉ★ > ryun("test.pyoyo")
```

<h4 align="left">Ouyutpuyut</h4>

```
Heyyo Woyrld
```

<h2 align="center">Docuyumentation</h2>

<h3 align="center">General</h3>

<p align="center"><code>python shÿell.py</code> opens the pythOyO shell. Running <code>ryun("test.pyoyo")</code> from the shell execuyutes code from the file <code>test.pyoyo</code>.</p>


<h3 align="center">Variables</h3>
<p align="center">Variables can be decluyuared using the keyword <code>pyease</code>.</p>

```py
pyease baka = 100
pyease tehe = "tyo"
pyease chan = 25
pyease baka = baka + 1
pyease tehe = 500
pyease chan = chan * 2

pyint(tehe)
pyint(baka)
pyint(chan)
```

<h4 align="left">Ouyutpuyut</h4>

```
500
101
50
```

<h3 align="center">Conditionals</h3>
<p align="center">IF《condition》THYEN《expression》EYIF《condition》THYEN《expression》</p>

```py
pyease tehe = 501

IF tehe == 502 THYEN pyease chan = "tehe is 502!" EYIF tehe == 501 THYEN pyease chan = "
is 501!" EYSE pyease chan = "tehe is 500!"

pyint(chan)
```

<h4 align="left">Ouyutpuyut</h4>

```
tehe is 501!
```

<h3 align="center">Loops</h3>

```py
FOR i = 0 TO 5 THYEN
	pyint("UyU")
END
```

<h4 align="left">Ouyutpuyut</h4>

```
UyU
UyU
UyU
UyU
UyU
```

<h3 align="center">Functions</h3>

```py
FYUNCTION oyofy(pyefix) -> pyefix + "OyO"

pyint(oyofy("This is pyth"))
```

<h4 align="left">Ouyutpuyut</h4>

```
This is pythOyO
```

<h3 align="center">Clear</h3>
<p align="center">You can clear the shell with the cyear command</p>

```
(｡･ÿ･｡)ﾉ★ > cyear
```


<h2 align="center">Contribuyuting</h2>
<p align="center">All contribuyutions are welcome, just make a puyull request!</p>

</br>

<h2 align="center">Testing</h2>
<p align="center">Unit tests are available through the unittest module. New test files must start with `test*.py` to be detected.</p>

```sh
python -m unittest
```

---

> Pythoyo logo [credit](https://www.pngegg.com/)


> Thank youyu @Haddle for making VSCode language support for PythOyO

> Thank youyu @Tulip-0333 for helping with putting PythOyO up on PyPi

<h5 align="left">uyu</h5>
